import React from "react";
import PropTypes from "prop-types";
import clsx from "clsx";
import { useTheme } from "@mui/material/styles";
import { AppBar, Toolbar, Typography, IconButton } from "@mui/material";
import MenuIcon from "@mui/icons-material/Menu";
import ProfileButton from "./ProfileButton";
import LightDarkToggle from "./LightDarkToggle";
import SensitiveInfoToggle from "./SensitiveInfoToggle";
import { getStyles } from "./styles";

const TopBar = ({ open, handleDrawerOpen }) => {
  const theme = useTheme();
  const styles = getStyles(theme);

  return (
    <AppBar
      position="fixed"
      sx={clsx(styles.appBar, {
        [styles.appBarShift]: open
      })}
    >
      <Toolbar>
        <IconButton
          color="inherit"
          aria-label="open drawer"
          onClick={handleDrawerOpen}
          edge="start"
          sx={clsx(styles.menuButton, {
            [styles.hide]: open
          })}
        >
          <MenuIcon />
        </IconButton>
        <Typography variant="h6" noWrap sx={styles.title}>
          Network resurrector
        </Typography>
        <SensitiveInfoToggle />
        <LightDarkToggle />
        <ProfileButton />
      </Toolbar>
    </AppBar>
  );
};

TopBar.propTypes = {
  open: PropTypes.bool.isRequired,
  handleDrawerOpen: PropTypes.func.isRequired
};

export default TopBar;
